@@ -156,7 +156,7 @@ def get_except_dic(d: dict, *arg):
     :param arg: 需要去除的key
     :return: 去除指定key后的字典（原字典中没有指定的key也不会报错）
     """
-    c = set(d) - set(arg)
+    c = set(d) - (set(d) - set(arg))
     for key in c:
         del d[key]
     return d
